Coverage report

# Coverage report: 28%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 2981 | 2038 | 0 | 488 | 9 | 28%
__init__.py | 3 | 0 | 0 | 2 | 0 | 100%
__main__.py | 29 | 29 | 0 | 8 | 0 | 0%
api/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
api/assets.py | 6 | 3 | 0 | 2 | 0 | 38%
api/cli.py | 203 | 203 | 0 | 34 | 0 | 0%
api/cli_content.py | 46 | 46 | 0 | 0 | 0 | 0%
api/cmd.py | 189 | 189 | 0 | 56 | 0 | 0%
api/cmd_helper.py | 298 | 298 | 0 | 132 | 0 | 0%
api/constants.py | 2 | 0 | 0 | 0 | 0 | 100%
api/database.py | 34 | 34 | 0 | 20 | 0 | 0%
api/email.py | 24 | 18 | 0 | 6 | 0 | 20%
api/enhance.py | 7 | 7 | 0 | 0 | 0 | 0%
api/file.py | 80 | 63 | 0 | 28 | 0 | 16%
api/forms.py | 7 | 4 | 0 | 4 | 0 | 27%
api/html.py | 12 | 3 | 0 | 0 | 0 | 75%
api/info.py | 4 | 4 | 0 | 0 | 0 | 0%
api/models.py | 37 | 20 | 0 | 10 | 0 | 36%
api/module.py | 38 | 15 | 0 | 2 | 0 | 58%
api/security.py | 14 | 9 | 0 | 4 | 0 | 28%
api/templates.py | 3 | 1 | 0 | 0 | 0 | 67%
api/tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
api/tests/conftest.py | 47 | 37 | 0 | 0 | 0 | 21%
api/tests/test_cli.py | 385 | 385 | 0 | 10 | 0 | 0%
api/tests/test_cli_integration.py | 31 | 31 | 0 | 2 | 0 | 0%
api/tests/test_email.py | 0 | 0 | 0 | 0 | 0 | 100%
api/tests/test_models.py | 50 | 50 | 0 | 0 | 0 | 0%
api/tests/test_print_info.py | 11 | 11 | 0 | 0 | 0 | 0%
api/tests/test_templates.py | 5 | 5 | 0 | 0 | 0 | 0%
api/tests/test_validators.py | 24 | 0 | 0 | 0 | 0 | 100%
api/validators.py | 31 | 11 | 0 | 8 | 0 | 51%
app.py | 136 | 22 | 0 | 30 | 8 | 81%
autoapp.py | 3 | 3 | 0 | 0 | 0 | 0%
config.py | 55 | 0 | 0 | 0 | 0 | 100%
conftest.py | 95 | 13 | 0 | 4 | 1 | 86%
init.py | 17 | 0 | 0 | 0 | 0 | 100%
manage.py | 3 | 3 | 0 | 2 | 0 | 0%
modules/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/appointment/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/appointment/models.py | 8 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/appointment/view.py | 101 | 53 | 0 | 4 | 0 | 46%
modules/box__bizhelp/contact/forms.py | 9 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/contact/global.py | 4 | 1 | 0 | 0 | 0 | 75%
modules/box__bizhelp/contact/models.py | 17 | 5 | 0 | 0 | 0 | 71%
modules/box__bizhelp/contact/view.py | 42 | 21 | 0 | 4 | 0 | 46%
modules/box__bizhelp/page/forms.py | 9 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/page/models.py | 17 | 5 | 0 | 0 | 0 | 71%
modules/box__bizhelp/page/view.py | 51 | 21 | 0 | 4 | 0 | 55%
modules/box__bizhelp/people/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/people/models.py | 18 | 0 | 0 | 0 | 0 | 100%
modules/box__bizhelp/people/view.py | 140 | 97 | 0 | 10 | 0 | 29%
modules/box__default/appadmin/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__default/appadmin/admin.py | 21 | 5 | 0 | 2 | 0 | 70%
modules/box__default/appadmin/view.py | 158 | 102 | 0 | 36 | 0 | 29%
modules/box__default/auth/decorators.py | 11 | 3 | 0 | 2 | 0 | 62%
modules/box__default/auth/forms.py | 22 | 3 | 0 | 2 | 0 | 79%
modules/box__default/auth/models.py | 78 | 30 | 0 | 6 | 0 | 57%
modules/box__default/auth/view.py | 113 | 70 | 0 | 26 | 0 | 31%
modules/box__default/base/view.py | 7 | 1 | 0 | 0 | 0 | 86%
modules/box__default/dashboard/view.py | 40 | 22 | 0 | 16 | 0 | 32%
modules/box__default/settings/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__default/settings/helpers.py | 9 | 6 | 0 | 2 | 0 | 27%
modules/box__default/settings/models.py | 15 | 6 | 0 | 0 | 0 | 60%
modules/box__default/settings/view.py | 0 | 0 | 0 | 0 | 0 | 100%
modules/box__default/theme/global.py | 34 | 18 | 0 | 0 | 0 | 47%
modules/box__default/theme/view.py | 53 | 26 | 0 | 4 | 0 | 47%
modules/resource/view.py | 22 | 5 | 0 | 0 | 0 | 77%
modules/www/global.py | 1 | 0 | 0 | 0 | 0 | 100%
modules/www/view.py | 16 | 3 | 0 | 0 | 0 | 81%
shopyo_admin.py | 29 | 11 | 0 | 4 | 0 | 55%
wsgi.py | 7 | 7 | 0 | 2 | 0 | 0%

No items found using the specified filter.